/*************************************************************************************
 Data Visualization - Basic 3D Demo                

 Author: Weidi Zhang                        
 Supervisor: George Legrady                           

 Purpose: Show how to present volume data in a basic 3D environment     

 Usage:

1.Left-clicking and dragging will rotate the camera position about the center of the sketch
2.right-clicking and dragging will pan the camera position without rotation
3.using the mouse wheel (scrolling) will move the camera closer or further from the center of the sketch. 

2.Press 'a' 's''d''f' will show four different albums respectively

step 1. preload files
step 2. setup - initialize data and get basic information
step 3. draw - draw data titles and labels
step 4. user interface design and user interactions
 *************************************************************************************/


let table;
let albumName = ['Back to black', 'Vampire forest', '19', 'Fleet foxes'];
let color = ['yellow','red','green','lightblue'];
let dataMatrix = [];
let albumMax = [];
let albumMin = [];
let boxSize=370;
let mapMin=boxSize/2, mapMax=-boxSize/2;
let numRows, numCols;
let cellDepth=boxSize/11, cellWidth=boxSize/9;
let albumShow = [];//boolean


function preload(){
    table = loadTable("data/SoulVsIndieRock.csv",'csv','header'); 
    Gotham = loadFont('data/Gotham-Bold.otf');
    DIN = loadFont('data/DIN.otf');
}

function setup(){
    print(albumMax[4]);
    createCanvas(windowWidth,windowHeight,WEBGL); // processing we use size(x,y, P3D)
    // Sets a perspective projection for the camera in a 3D sketch.
    // perspective([fovy], [aspect], [near], [far])
    perspective(PI / 3.0, width / height, 0.1, 5000);
    // get the basic information of data
    numRows= table.getRowCount();
    numCols= table.getColumnCount(); 
    print("Rows: " + numRows + " , Columns: " + numCols);  

    // retrieve data from table
    for(let i = 0; i <numRows; i++){
        dataMatrix[i]= []; //create nested array
        for(let j = 0; j < numCols-4; j++){
            dataMatrix[i][j] = table.getNum(i,j+4);
        }
    }

    //find Max and Min for each four albums and print 
    for(let i=0;i<albumName.length;i++){
        findMinMaxValue(albumName[i],i,0,0); 
        //boolean are true
        albumShow[i]=true;
    }  
}



function draw(){
    background(35);

    //Allows movement around a 3D sketch using a mouse
    orbitControl();
    lights();
    
    //origin in WEBGL is the center of the canvas
    fill(180,180,180,80);
    box(boxSize);
    for(let i=0;i<numRows;i++){
        if(albumShow[i]){
             drawData(i);
        }
    }
    drawLabel();
  

}

function keyTyped() {
    if (key === 'a') {
        albumShow[0] =!albumShow[0];
    }else if(key === 's'){
        albumShow[1] =!albumShow[1];
    }else if(key === 'd'){
        albumShow[2] =!albumShow[2];
    }else if(key === 'f'){
        albumShow[3] =!albumShow[3];
    }

}




















